==> trade-center-api-0.2.0-20161102.071429-1-sources.jar: cn/com/duiba/order/center/api/dto/CreditsMessage.java <==
package cn.com.duiba.order.center.api.dto;

import java.io.Serializable;
import java.util.Map;

/**
 * 扣/加积分消息封装类
 */
public class CreditsMessage implements Serializable {

	/**
	 * 
	 */
	private static final long serialVersionUID = -2892559155424549092L;

	public static final String HTTP_GET = "get";
	public static final String HTTP_POST = "post";

	/** 普通兑换 */
	public static final String TYPE_EXCHANGE = "mall";
	/** 小游戏 */
	public static final String TYPE_LITTLE_GAME = "littleGame";
	/** 今日笔抢 */
	public static final String TYPE_ACTIVITY_ROB = "rob";

	private String relationId;
	private String relationType;
	private String appId;
	private String consumerId;
	private String httpType;
	private String httpUrl;
	private Map<String, String> authParams;
	private Map<String, String> params;
	private Long timestamp;

	public String getRelationId() {
		return relationId;
	}

	public void setRelationId(String relationId) {
		this.relationId = relationId;
	}

	public String getRelationType() {
		return relationType;
	}

	public void setRelationType(String relationType) {
		this.relationType = relationType;
	}

	public String getAppId() {
		return appId;
	}

	public void setAppId(String appId) {
		this.appId = appId;
	}

	public String getConsumerId() {
		return consumerId;
	}

	public void setConsumerId(String consumerId) {
		this.consumerId = consumerId;
	}

	public String getHttpType() {
		return httpType;
	}

	public void setHttpType(String httpType) {
		this.httpType = httpType;
	}

	public String getHttpUrl() {
		return httpUrl;
	}

	public void setHttpUrl(String httpUrl) {
		this.httpUrl = httpUrl;
	}

	public Map<String, String> getParams() {
		return params;
	}

	public void setParams(Map<String, String> params) {
		this.params = params;
	}

	public Map<String, String> getAuthParams() {
		return authParams;
	}

	public void setAuthParams(Map<String, String> authParams) {
		this.authParams = authParams;
	}

	public Long getTimestamp() {
		return timestamp;
	}

	public void setTimestamp(Long timestamp) {
		this.timestamp = timestamp;
	}

}

==> trade-center-api-0.8.2-20170227.055127-1-sources.jar: cn/com/duiba/order/center/api/dto/CreditsMessage.java <==
package cn.com.duiba.order.center.api.dto;

import java.io.Serializable;
import java.util.Map;

/**
 * 扣/加积分消息封装类
 */
public class CreditsMessage implements Serializable {

	/**
	 * 
	 */
	private static final long serialVersionUID = -2892559155424549092L;

	public static final String HTTP_GET = "get";
	public static final String HTTP_POST = "post";

	/** 普通兑换 */
	public static final String TYPE_EXCHANGE = "mall";
	/** 小游戏 */
	public static final String TYPE_LITTLE_GAME = "littleGame";
	/** 积分游戏 */
	public static final String TYPE_CREDITS_GAME = "creditsGame";
	/** 今日必抢 */
	public static final String TYPE_ACTIVITY_ROB = "rob";
	/** 活动工具*/
	public static final String TYPE_HDTOOL = "htool";
	/** 单品抽奖*/
	public static final String TYPE_SINGLELOTTERY = "singleLottery";
	/** guess */
	public static final String TYPE_GUESS = "guess";
	/** quizz */
	public static final String TYPE_QUIZZ = "quizz";
	

	private String relationId;
	private String relationType;
	private String appId;
	private String consumerId;
	private String httpType;
	private String httpUrl;
	private Map<String, String> authParams;
	private Map<String, String> params;
	private Long timestamp;

	public String getRelationId() {
		return relationId;
	}

	public void setRelationId(String relationId) {
		this.relationId = relationId;
	}

	public String getRelationType() {
		return relationType;
	}

	public void setRelationType(String relationType) {
		this.relationType = relationType;
	}

	public String getAppId() {
		return appId;
	}

	public void setAppId(String appId) {
		this.appId = appId;
	}

	public String getConsumerId() {
		return consumerId;
	}

	public void setConsumerId(String consumerId) {
		this.consumerId = consumerId;
	}

	public String getHttpType() {
		return httpType;
	}

	public void setHttpType(String httpType) {
		this.httpType = httpType;
	}

	public String getHttpUrl() {
		return httpUrl;
	}

	public void setHttpUrl(String httpUrl) {
		this.httpUrl = httpUrl;
	}

	public Map<String, String> getParams() {
		return params;
	}

	public void setParams(Map<String, String> params) {
		this.params = params;
	}

	public Map<String, String> getAuthParams() {
		return authParams;
	}

	public void setAuthParams(Map<String, String> authParams) {
		this.authParams = authParams;
	}

	public Long getTimestamp() {
		return timestamp;
	}

	public void setTimestamp(Long timestamp) {
		this.timestamp = timestamp;
	}

}
